@@ -1,32 +1,35 @@
-// -*- mode: c++; -*-
-
-////////////////////////////////////////////////////////////////////////////////
-
-// Copyright 2014 Nick Polson, James Scott, and Jesse Windle.
+// -*- mode: c++;  c-basic-offset: 4 -*-
+// (C) Nicholas Polson, James Scott, Jesse Windle, 2012-2019
 
 // This file is part of BayesLogit.
 
 // BayesLogit is free software: you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
-// Foundation, either version 3 of the License, or any later version.
+// Foundation, either version 3 of the License, or (at your option) any later
+// version.
 
 // BayesLogit is distributed in the hope that it will be useful, but WITHOUT ANY
 // WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 // A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 
 // You should have received a copy of the GNU General Public License along with
-// BayesLogit.  If not, see <http://www.gnu.org/licenses/>.
+// BayesLogit.  If not, see <https://www.gnu.org/licenses/>.
 
-////////////////////////////////////////////////////////////////////////////////
 
 // See <http://arxiv.org/abs/1205.0310> for implementation details.
 
 #ifndef __POLYAGAMMA__
 #define __POLYAGAMMA__
 
-#include "RNG.h"
+#include "simple_RNG_wrapper.h"
+#include "truncated_norm.h"
+#include "truncated_gamma.h"
+#include "inverse_gaussian.h"
+
 #include <cmath>
 #include <vector>
+#include <stdio.h>
+#include <stdexcept>
 
 using std::vector;
 
@@ -51,9 +54,9 @@ class PolyaGamma
 
   // Draw.
   // double draw(double n, double z, RNG& r);
-  double draw(int n, double z, RNG& r);
-  double draw_sum_of_gammas(double n, double z, RNG& r);
-  double draw_like_devroye(double z, RNG& r);
+  double draw(int n, double z);
+  double draw_sum_of_gammas(double n, double z);
+  double draw_like_devroye(double z);
 
   //void draw(MF x, double a, double z, RNG& r);
   //void draw(MF x, MF a, MF z, RNG& r);
@@ -65,7 +68,7 @@ class PolyaGamma
   double a(int n, double x);
   double pigauss(double x, double Z);
   double mass_texpon(double Z);
-  double rtigauss(double Z, RNG& r);
+  double rtigauss(double Z);
 
   static double jj_m1(double b, double z);
   static double jj_m2(double b, double z);
